@@ -10,7 +10,7 @@ import boto3
 from PIL import Image
 from .config import EXTENSION_LISTS
 from .config import TEMP
-from config import BUCKET_NAME
+from config import S3_BUCKET_NAME
 from PIL import Image, ImageSequence
 
 
@@ -27,7 +27,7 @@ def upload_file_to_s3(json_path):
         for file in os.listdir(json_path):
             s3_json_path = os.path.join(json_path, file)
             S3.meta.client.upload_file(
-                s3_json_path, BUCKET_NAME, s3_json_path)
+                s3_json_path, S3_BUCKET_NAME, s3_json_path)
     except Exception as error:
         return error
 
